pub struct ListSessionsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListSessions.
Lists the sessions in a workgroup that are in an active state like CREATING, CREATED, IDLE, or BUSY. Newer sessions are listed first; older sessions are listed later.
Implementations
Sourceimpl ListSessionsFluentBuilder
impl ListSessionsFluentBuilder
Sourcepub fn as_input(&self) -> &ListSessionsInputBuilder
pub fn as_input(&self) -> &ListSessionsInputBuilder
Access the ListSessions as a reference.
Sourcepub async fn send(
self,
) -> Result<ListSessionsOutput, SdkError<ListSessionsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListSessionsOutput, SdkError<ListSessionsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListSessionsOutput, ListSessionsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListSessionsOutput, ListSessionsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListSessionsPaginator
pub fn into_paginator(self) -> ListSessionsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to which the session belongs.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to which the session belongs.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to which the session belongs.
Sourcepub fn state_filter(self, input: SessionState) -> Self
pub fn state_filter(self, input: SessionState) -> Self
A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn set_state_filter(self, input: Option<SessionState>) -> Self
pub fn set_state_filter(self, input: Option<SessionState>) -> Self
A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn get_state_filter(&self) -> &Option<SessionState>
pub fn get_state_filter(&self) -> &Option<SessionState>
A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of sessions to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of sessions to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of sessions to return.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.