#[non_exhaustive]pub struct ListSessionsOutputBuilder { /* private fields */ }Expand description
A builder for ListSessionsOutput.
Implementations
Sourceimpl ListSessionsOutputBuilder
impl ListSessionsOutputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn sessions(self, input: SessionSummary) -> Self
pub fn sessions(self, input: SessionSummary) -> Self
Appends an item to sessions.
To override the contents of this collection use set_sessions.
A list of sessions.
Sourcepub fn set_sessions(self, input: Option<Vec<SessionSummary>>) -> Self
pub fn set_sessions(self, input: Option<Vec<SessionSummary>>) -> Self
A list of sessions.
Sourcepub fn get_sessions(&self) -> &Option<Vec<SessionSummary>>
pub fn get_sessions(&self) -> &Option<Vec<SessionSummary>>
A list of sessions.
Sourcepub fn build(self) -> ListSessionsOutput
pub fn build(self) -> ListSessionsOutput
Consumes the builder and constructs a ListSessionsOutput.